/* Description: A simple C++ sample of using the GPC COM library.
 *				In this sample we will load two polygon difinition files
 *				from the local C drive and intersect them.
 *				For simplicity, this sample takes use of Smart Pointers.
 *
 * Author: Tom Wolf (tom@www.aftershock.co.il)
 */

/*import GPCCOM library*/
#import "..\..\BIN\GPCCOM.DLL" no_namespace

#include <conio.h> // _getch()
#include <iostream>

using namespace std;

#include <windows.h> // for GetTickCount

int main()
{
	CoInitialize(NULL); //init COM for the primary thread
	{
		IGPC_PolygonPtr spPolygonSubject(__uuidof(GPC_Polygon)); //declare and create subject polygon (will hold england)
		IGPC_PolygonPtr spPolygonClip(__uuidof(GPC_Polygon)); //declare and create clip polygon (will hold arrows)

		IGPC_PolygonPtr spPolygonRet; //declare returned polygon

		/*try loading the "england" polygon*/
		if (VARIANT_TRUE == spPolygonSubject->Load(L"c:\\england.gpf", VARIANT_FALSE))
		{
			/*try loading the "arrows" polygon*/
			if (VARIANT_TRUE == spPolygonClip->Load(L"c:\\arrows.gpf", VARIANT_FALSE))
			{
				double dwStart, dwEnd; //calculate performance

				dwStart = GetTickCount();
				spPolygonRet = spPolygonSubject->Clip(clipIntersection, spPolygonClip); //try intersecting them
				dwEnd = GetTickCount() - dwStart;

				if (NULL != spPolygonRet)
				{
					spPolygonRet->Save(L"c:\\ret.gpf", VARIANT_FALSE); //write polygon to local disk
					
					cout << "Successfully intersected polygons in: " << dwEnd << " milliseconds!" << endl;
				}
				else
				{
					cout << "Failed to clip polygons!" << endl;
				}
			}
			else
			{
				cout << "unable to load Arrows polygon!" << endl;
			}
		}
		else
		{
			cout << "Unable to load England polygon!" << endl;
		}

		_getch();
	}
	CoUninitialize();

	return 0;
}
